dag_cbor.utils
==============

.. automodule:: dag_cbor.utils

CBORDecodingError
-----------------

.. autoclass:: dag_cbor.utils.CBORDecodingError
    :members:

CBOREncodingError
-----------------

.. autoclass:: dag_cbor.utils.CBOREncodingError
    :members:

CBORError
---------

.. autoclass:: dag_cbor.utils.CBORError
    :members:

DAGCBORDecodingError
--------------------

.. autoclass:: dag_cbor.utils.DAGCBORDecodingError
    :members:

DAGCBOREncodingError
--------------------

.. autoclass:: dag_cbor.utils.DAGCBOREncodingError
    :members:

DAGCBORError
------------

.. autoclass:: dag_cbor.utils.DAGCBORError
    :members:

canonical_order_dict
--------------------

.. autofunction:: dag_cbor.utils.canonical_order_dict

check_key_compliance
--------------------

.. autofunction:: dag_cbor.utils.check_key_compliance
